@@ -22,7 +22,7 @@ from ipywidgets import (Text, Textarea, Label, HBox, VBox, Dropdown,
 
 from cbm.utils import config, data_options
 from cbm.ipycbm.ipy_get import get_maps
-from cbm.get import time_series, parcel_info, chip_images, background
+from cbm.get import time_series, parcel_info
 
 
 def get():
@@ -48,13 +48,11 @@ def get():
         if values['set']['data_source'] == 'api':
             api_values = config.read('api_options.json')
             for aoi in api_values['aois']:
-                desc = f"{api_values['aois'][aoi]['description']}"
-                options[(desc, aoi)] = api_values['aois'][aoi]['year']
+                options[(aoi.upper(), aoi)] = api_values['aois'][aoi]['years']
         elif values['set']['data_source'] == 'direct':
             values = config.read('api_options.json')
             for aoi in values['dataset']:
-                desc = f"{values['dataset'][aoi]['description']}"
-                options[(f"{desc} ({aoi})", aoi)] = [aoi.split('_')[-1]]
+                options[(f"{aoi.upper()} ({aoi})", aoi)] = [aoi.split('_')[-1]]
         return options
 
     def aois_years():
@@ -63,7 +61,7 @@ def get():
         if values['set']['data_source'] == 'api':
             api_values = config.read('api_options.json')
             for aoi in api_values['aois']:
-                years[aoi] = api_values['aois'][aoi]['year']
+                years[aoi] = api_values['aois'][aoi]['years']
         elif values['set']['data_source'] == 'direct':
             values = config.read()
             for aoi in values['dataset']:
@@ -119,13 +117,19 @@ def get():
         year.disabled = years_disabled()
 
     def table_options_change(change):
+        api_values = config.read('api_options.json')
+        id_examples = api_values['aois'][change.new]['id_examples']
         try:
+            id_examples_label.value = ', '.join(str(x) for x in id_examples)
             year.options = aois_years()[change.new]
             year.disabled = years_disabled()
+            pid.value = str(id_examples[0])
         except Exception:
+            id_examples_label.value = ', '.join(str(x) for x in id_examples)
             aois.options = tuple(aois_options())
             year.options = aois_years()[aois.value]
             year.disabled = years_disabled()
+            pid.value = str(id_examples[0])
     aois.observe(table_options_change, 'value')
 
     info_method = Label("2. Select a method to download parcel data.")
@@ -147,11 +151,15 @@ def get():
     plat = Text(value='52.694', placeholder='Add lat', description='Lat:')
     wbox_lat_lot = VBox(children=[plat, plon])
 
-    info_pid = HTML("""Multiple parcel id codes can be added
-    (comma ',' separated, e.g.: 11111, 22222).""")
+    api_values = config.read('api_options.json')
+    id_examples = api_values['aois'][aois.value]['id_examples']
+
+    id_examples_label = Label(', '.join(str(x) for x in id_examples))
+    info_pid = HBox([Label("Multiple parcel ids can be added, e.g.: "),
+                     id_examples_label])
 
     pid = Textarea(
-        value='34296',
+        value=str(id_examples[0]),
         placeholder='12345, 67890',
         description='Parcel(s) ID:',
     )
@@ -173,7 +181,7 @@ def get():
     def bt_get_ids_on_click(b):
         with ppoly_out:
             try:
-                get_requests = data_source()
+                # get_requests = data_source()
                 ppoly_out.clear_output()
                 polygon = get_maps.polygon_map.feature_collection[
                     'features'][-1]['geometry']['coordinates'][0]
@@ -236,7 +244,11 @@ def get():
     pts_bands = data_options.pts_bands()
 
     pts_tstype = SelectMultiple(
-        options=data_options.pts_tstype(),
+        options=[
+            ("Sentinel-2 Level 2A", 's2'),
+            ("S1 Backscattering Coefficients", 'bs'),
+            ("S1 6-day Coherence (20m)", 'c6')
+        ],
         value=['s2'],
         rows=3,
         description='TS type:',
@@ -278,12 +290,12 @@ def get():
     )
 
     pci_start_date = DatePicker(
-        value=datetime.date(2019, 6, 1),
+        value=datetime.date(2020, 6, 1),
         description='Start Date',
     )
 
     pci_end_date = DatePicker(
-        value=datetime.date(2019, 6, 30),
+        value=datetime.date(2020, 6, 30),
         description='End Date',
     )
 
@@ -401,14 +413,14 @@ def get():
 
     def get_data(parcel):
         get_requests = data_source()
-        pid = parcel['pid'][0]
+        pid = str(parcel['pid'][0])
         source = config.get_value(['set', 'data_source'])
         if source == 'api':
             datapath = normpath(
-                join(paths.value, aois.value, year.value, str(pid)))
+                join(paths.value, aois.value, year.value, pid))
         elif source == 'direct':
             dataset = config.get_value(['set', 'dataset'])
-            datapath = normpath(join(paths.value, dataset, str(pid)))
+            datapath = normpath(join(paths.value, dataset, pid))
         file_pinf = normpath(join(datapath, 'info.json'))
         os.makedirs(dirname(file_pinf), exist_ok=True)
         with open(file_pinf, "w") as f:
@@ -452,7 +464,7 @@ def get():
         outlog(f"Finding parcel information for coordinates: {lon}, {lat}")
         parcel = parcel_info.by_location(aois.value, year.value, lon, lat,
                                          ptype.value, True, False, debug)
-        pid = parcel['pid'][0]
+        pid = str(parcel['pid'][0])
         outlog(f"The parcel '{pid}' was found at this location.")
         try:
             get_data(parcel)
