@@ -12,6 +12,7 @@ import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
 import matplotlib.dates as mdates
+from itertools import groupby
 from os.path import join, normpath, isfile
 from datetime import timedelta
 
@@ -19,103 +20,157 @@ from cbm.utils import config
 from cbm.get import parcel_info, time_series
 
 
-def ndvi(aoi, year, pid, ptype=None, cloud_free=True,
-         scl='3_8_9_10_11', debug=False):
+def all_equal(iterable):
+    "Returns True if all the elements are equal to each other"
+    g = groupby(iterable)
+    return next(g, True) and not next(g, False)
 
-    path = normpath(join(config.get_value(['paths', 'temp']),
-                         aoi, year, str(pid)))
 
-    file_info = normpath(join(path, 'info.json'))
-    if not isfile(file_info):
-        parcel_info.by_pid(aoi, year, pid)
-    with open(file_info, 'r') as f:
-        info_data = json.loads(f.read())
+def ndvi(aoi, year, pids, ptype=None, scl='3_8_9_10_11', std=True,
+         max_line_plots=10, errorbar=True, debug=False):
 
-    crop_name = info_data['cropname'][0]
-    area = info_data['area'][0]
+    if type(pids) is not list:
+        pids = [pids]
+    if max_line_plots > 20:
+        max_line_plots = 20
+        print("Can not plot more then 20 lines.")
+    if len(pids) > 50:
+        del pids[50:]
+        print("Currently supporting max 50 shading plots.",
+              "Will plot first 50 parcels")
 
-    file_ts = normpath(join(path, 'time_series_s2.csv'))
-    if not isfile(file_ts):
-        time_series.by_pid(aoi, year, pid, 's2', ptype, '', debug)
-    df = pd.read_csv(file_ts, index_col=0)
+    crop_names = []
+    for pid in pids:
+        pid = str(pid)
+        path = normpath(join(config.get_value(['paths', 'temp']),
+                             aoi, str(year), str(pid)))
+        file_info = normpath(join(path, 'info.json'))
+        if not isfile(file_info):
+            parcel_info.by_pid(aoi, year, pid)
+        with open(file_info, 'r') as f:
+            info_data = json.loads(f.read())
+        crop_names.append(info_data['cropname'][0])
 
-    df['date'] = pd.to_datetime(df['date_part'], unit='s')
-    start_date = df.iloc[0]['date'].date()
-    end_date = df.iloc[-1]['date'].date()
-    # print(f"From '{start_date}' to '{end_date}'.")
-
-    pd.set_option('max_colwidth', 200)
-    pd.set_option('display.max_columns', 20)
-
-    # Plot settings are confirm IJRS graphics instructions
-    plt.rcParams['axes.titlesize'] = 16
-    plt.rcParams['axes.labelsize'] = 14
-    plt.rcParams['xtick.labelsize'] = 12
-    plt.rcParams['ytick.labelsize'] = 12
-    plt.rcParams['legend.fontsize'] = 14
-
-    df.set_index(['date'], inplace=True)
-
-    dfB4 = df[df.band.isin(['B4', 'B04'])].copy()
-    dfB8 = df[df.band.isin(['B8', 'B08'])].copy()
-    datesFmt = mdates.DateFormatter('%-d %b %Y')
-
-    # Plot Cloud free NDVI.
-    dfNDVI = (dfB8['mean'] - dfB4['mean']) / (dfB8['mean'] + dfB4['mean'])
-
-    if 'hist' in df.columns:
-        df['cf'] = pd.Series(dtype='str')
-        scls = scl.split('_')
-        for index, row in df.iterrows():
-            if any(x in scls for x in [*json.loads(row['hist'].replace("\'",
-                                                                       "\""))]):
-                df.at[index, 'cf'] = 'False'
-            else:
-                df.at[index, 'cf'] = 'True'
-        cloudfree = (df['cf'] == 'True')
-        cloudfree = cloudfree[~cloudfree.index.duplicated()]
+    parcel_peers = True
+    if len(pids) == 1:
+        plot_title = f"NDVI profile for parcel '{pids[0]}', crop type: {crop_names[0]}."
+        cloudfreelabel = "Cloud free"
+    elif all_equal(crop_names):
+        plot_title = f"NDVI profiles for crop type: {crop_names[0]}."
+        cloudfreelabel = pid  # , area: {area:.1f}sqm"
     else:
-        dfSC = df[df.band == 'SC'].copy()
-        cloudfree = ((dfSC['mean'] >= 4) & (dfSC['mean'] < 6))
+        plot_title = "NDVI profiles"
+        parcel_peers = False
 
     fig = plt.figure(figsize=(16.0, 10.0))
     axb = fig.add_subplot(1, 1, 1)
 
-    axb.set_title(f"Parcel {pid} (crop: {crop_name}, area: {area:.2f} sqm)")
+    pcount = 1
 
-    axb.set_xlabel("Date")
-    axb.xaxis.set_major_formatter(datesFmt)
+    for pid in pids:
+        pid = str(pid)
+        path = normpath(join(config.get_value(['paths', 'temp']),
+                             aoi, str(year), str(pid)))
 
-    axb.set_ylabel(r'NDVI')
-    axb.plot(dfNDVI.index, dfNDVI, linestyle=' ', marker='s',
-             markersize=10, color='DarkBlue',
-             fillstyle='none', label='NDVI')
-    if cloud_free:
+        file_info = normpath(join(path, 'info.json'))
+        with open(file_info, 'r') as f:
+            info_data = json.loads(f.read())
+
+        crop_name = info_data['cropname'][0]
+        area = info_data['area'][0]
+
+        file_ts = normpath(join(path, 'time_series_s2.csv'))
+        if not isfile(file_ts):
+            time_series.by_pid(aoi, year, pid, 's2', ptype, '', debug)
+        df = pd.read_csv(file_ts, index_col=0)
+
+        df['date'] = pd.to_datetime(df['date_part'], unit='s')
+        start_date = df.iloc[0]['date'].date()
+        end_date = df.iloc[-1]['date'].date()
+        # print(f"From '{start_date}' to '{end_date}'.")
+
+        pd.set_option('max_colwidth', 200)
+        pd.set_option('display.max_columns', 20)
+
+        # Plot settings are confirm IJRS graphics instructions
+        plt.rcParams['axes.titlesize'] = 16
+        plt.rcParams['axes.labelsize'] = 14
+        plt.rcParams['xtick.labelsize'] = 12
+        plt.rcParams['ytick.labelsize'] = 12
+        plt.rcParams['legend.fontsize'] = 14
+
+        df.set_index(['date'], inplace=True)
+
+        dfB4 = df[df.band.isin(['B4', 'B04'])].copy()
+        dfB8 = df[df.band.isin(['B8', 'B08'])].copy()
+        datesFmt = mdates.DateFormatter('%-d %b %Y')
+
+        # Plot Cloud free NDVI.
+        dfNDVI = (dfB8['mean'] - dfB4['mean']) / (dfB8['mean'] + dfB4['mean'])
+
+        axb.set_xlabel("Date")
+        axb.xaxis.set_major_formatter(datesFmt)
+
+        if len(pids) == 1:
+            axb.set_ylabel(r'NDVI')
+            axb.plot(dfNDVI.index, dfNDVI, linestyle=' ', marker='s',
+                     markersize=10, color='lightgray',
+                     fillstyle='none', label='All observations')
+
+        if not parcel_peers:
+            cloudfreelabel = f"{pid}, {crop_name}"
+
+        if 'hist' in df.columns:
+            df['cf'] = pd.Series(dtype='str')
+            scls = scl.split('_')
+            for index, row in df.iterrows():
+                if any(x in scls for x in [*json.loads(row['hist'].replace("\'", "\""))]):
+                    df.at[index, 'cf'] = 'False'
+                else:
+                    df.at[index, 'cf'] = 'True'
+            cloudfree = (df['cf'] == 'True')
+            cloudfree = cloudfree[~cloudfree.index.duplicated()]
+        else:
+            dfSC = df[df.band == 'SC'].copy()
+            cloudfree = ((dfSC['mean'] >= 4) & (dfSC['mean'] < 6))
+        if std or errorbar:
+            dfstd = ((dfB8['p75'] - dfB4['p25']) / 50000)
+            cloufreestd = dfstd[dfstd.index.isin(dfNDVI[cloudfree].index)]
         try:
-            axb.plot(dfNDVI[cloudfree].index, dfNDVI[cloudfree],
-                     linestyle=' ', marker='P',
-                     markersize=10, color='Red',
-                     fillstyle='none', label='Cloud free NDVI')
+            if pcount <= max_line_plots:
+                axb.plot(dfNDVI[cloudfree].index, dfNDVI[cloudfree],
+                         linestyle='--', marker='P', markersize=10,
+                         fillstyle='none', label=cloudfreelabel)
+                pcount += 1
+                if errorbar:
+                    axb.errorbar(dfNDVI[cloudfree].index, dfNDVI[cloudfree],
+                                 cloufreestd, fmt=' ', color='Gray',
+                                 linewidth=2, capsize=4, alpha=0.5)
+            if std:
+                axb.fill_between(dfNDVI[cloudfree].index,
+                                 dfNDVI[cloudfree] - cloufreestd,
+                                 dfNDVI[cloudfree] + cloufreestd,
+                                 color='b', alpha=0.03)
         except Exception as err:
             message = f"Could not mark cloud free images: {err}"
 
-    axb.set_xlim(start_date, end_date + timedelta(1))
-    axb.set_ylim(0, 1.0)
-
-    axb.legend(frameon=False)
+        axb.set_xlim(start_date, end_date + timedelta(1))
+        axb.set_ylim(0, 1.0)
 
+        axb.legend(frameon=False)
     if 'message' in locals():
         print(message)
+    axb.set_title(plot_title)
 
     return plt.show()
 
 
-def s2(aoi, year, pid, ptype=None, bands=['B02'], cloud_free=True,
-       scl='3_8_9_10_11', debug=False):
+def s2(aoi, year, pid, ptype=None, bands=['B08'], scl='3_8_9_10_11',
+       debug=False):
     if type(bands) is str:
         bands = [bands]
     path = normpath(join(config.get_value(['paths', 'temp']),
-                         aoi, year, str(pid)))
+                         aoi, str(year), str(pid)))
 
     parcel_file = normpath(join(path, 'info.json'))
     if not isfile(parcel_file):
@@ -180,7 +235,6 @@ def s2(aoi, year, pid, ptype=None, bands=['B02'], cloud_free=True,
     axb.set_title(f"Parcel {pid} (crop: {crop_name}, area: {area:.2f} ha)")
     axb.set_xlabel("Date")
     axb.xaxis.set_major_formatter(datesFmt)
-
     axb.set_ylabel(r'DN')
 
     colors = {"B01": "Grey",
@@ -190,7 +244,7 @@ def s2(aoi, year, pid, ptype=None, bands=['B02'], cloud_free=True,
               "B05": "Grey",
               "B06": "Grey",
               "B07": "Grey",
-              "B08": "magenta",
+              "B08": "darkviolet",
               "B8A": "Grey",
               "B09": "Grey",
               "B10": "Grey",
@@ -204,7 +258,7 @@ def s2(aoi, year, pid, ptype=None, bands=['B02'], cloud_free=True,
               "B5": "Grey",
               "B6": "Grey",
               "B7": "Grey",
-              "B8": "magenta",
+              "B8": "darkviolet",
               "B9": "Grey"
               }
 
@@ -212,34 +266,27 @@ def s2(aoi, year, pid, ptype=None, bands=['B02'], cloud_free=True,
     for b in bands:
         axb.plot(dfb[b].index, dfb[b]['mean'], linestyle=' ', marker='o',
                  markersize=8, color=colors[b],
-                 fillstyle='none', label=b)
+                 fillstyle='none', label=b, alpha=0.5)
 
         seriesB[b] = pd.Series(dfb[b]['mean'], index=dfb[b].index)
-        if cloud_free:
-            try:
-                axb.plot(seriesB[b][cloudfree].index, seriesB[b][cloudfree],
-                         linestyle=' ', marker='x',
-                         markersize=8, color=colors[b],
-                         fillstyle='none', label=f'{b} Cloud free')
-            except Exception as err:
-                message = f"Could not mark cloud free images: {err}"
+        axb.plot(seriesB[b][cloudfree].index, seriesB[b][cloudfree],
+                 linestyle='--', marker='x',
+                 markersize=8, color=colors[b],
+                 fillstyle='none', label=f'{b} Cloud free')
 
     axb.set_xlim(start_date, end_date + timedelta(1))
     axb.set_ylim(0, 10000)
-
     axb.legend(frameon=False)
 
-    if 'message' in locals():
-        print(message)
-
     return plt.show()
 
 
-def s1_bs(aoi, pid):
-    path = normpath(join(config.get_value(['paths', 'temp']), aoi, str(pid)))
+def s1_bs(aoi, year, pid, ptype=None, debug=False):
+    path = normpath(join(config.get_value(['paths', 'temp']),
+                         aoi, str(year), str(pid)))
     file_info = normpath(join(path, 'info.json'))
     if not isfile(file_info):
-        parcel_info.by_pid(aoi, pid)
+        parcel_info.by_pid(aoi, year, pid, ptype, True)
     with open(file_info, 'r') as f:
         info_data = json.loads(f.read())
 
@@ -248,7 +295,7 @@ def s1_bs(aoi, pid):
 
     file_ts = normpath(join(path, 'time_series_bs.csv'))
     if not isfile(file_ts):
-        time_series.by_pid(aoi, pid, 'bs')
+        time_series.by_pid(aoi, year, pid, 'bs', ptype, '', debug)
     df = pd.read_csv(file_ts, index_col=0)
 
     df['date'] = pd.to_datetime(df['date_part'], unit='s')
@@ -273,8 +320,8 @@ def s1_bs(aoi, pid):
     datesFmt = mdates.DateFormatter('%-d %b %Y')
     df = df[df['mean'] >= 0]  # to remove negative values
 
-    dfVV = df[df.band == 'VV'].copy()
-    dfVH = df[df.band == 'VH'].copy()
+    dfVV = df[df.band == 'VVb'].copy()
+    dfVH = df[df.band == 'VHb'].copy()
     fig = plt.figure(figsize=(16.0, 10.0))
     axb = fig.add_subplot(1, 1, 1)
 
@@ -300,11 +347,12 @@ def s1_bs(aoi, pid):
     return plt.show()
 
 
-def s1_c6(aoi, pid):
-    path = normpath(join(config.get_value(['paths', 'temp']), aoi, str(pid)))
+def s1_c6(aoi, year, pid, ptype=None, debug=False):
+    path = normpath(join(config.get_value(['paths', 'temp']),
+                         aoi, year, str(pid)))
     file_info = normpath(join(path, 'info.json'))
     if not isfile(file_info):
-        parcel_info.by_pid(aoi, pid)
+        parcel_info.by_pid(aoi, year, pid, ptype, True)
     with open(file_info, 'r') as f:
         info_data = json.loads(f.read())
 
@@ -313,7 +361,7 @@ def s1_c6(aoi, pid):
 
     file_ts = normpath(join(path, 'time_series_c6.csv'))
     if not isfile(file_ts):
-        time_series.by_pid(aoi, pid, 'c6')
+        time_series.by_pid(aoi, year, pid, 'c6', ptype, '', debug)
     df = pd.read_csv(file_ts, index_col=0)
 
     df['date'] = pd.to_datetime(df['date_part'], unit='s')
@@ -336,8 +384,8 @@ def s1_c6(aoi, pid):
 
     # Plot Coherence
 
-    dfVV = df[df.band == 'VV'].copy()
-    dfVH = df[df.band == 'VH'].copy()
+    dfVV = df[df.band == 'VVc'].copy()
+    dfVH = df[df.band == 'VHc'].copy()
     fig = plt.figure(figsize=(16.0, 10.0))
     axb = fig.add_subplot(1, 1, 1)
 
